ziggy.hdmc.hdfs

Package ziggy :: Package hdmc :: Package hdfs |
[hide private]
[frames] | no frames]

# Package hdfs

source code

Created on Jul 28, 2010 Access functions for files and directories stored in HDFS (Hadoop File System).

Author: dwmclary

Submodules | [hide private]
ziggy.hdmc.hdfs.hdfs_access: Created on May 17, 2010 ziggy.hdmc.hdfs.hdfs_config

Functions | [hide private]
copyToHDFS(filename, hdfs_filename) | source code
cat(filename) Runs HDFS cat on a filename or glob passed as a string Returns the result as a string read from STOUT | source code
ls(filename) Runs HDFS ls on a directory or glob passed as a string Returns the result as a string read from STOUT | source code
rm(filename) Runs HDFS rmr on a filename or glob passed as a string Returns the result as a string read from STOUT | source code
copyFromHDFS(hdfs_filename, filename) | source code

Variables | [hide private]
| __author__ = ``'``D. McClary (dan.mcclary@northwestern.edu)``'``
| __package__ = ``'``ziggy.hdmc.hdfs``'``